[nautilus-actions] na_exporter renamed to fma_exporter



commit c430a9bdfc746f119495417da8f38bfb4ac4a709
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 23:23:27 2015 +0200

    na_exporter renamed to fma_exporter

 src/core/Makefile.am                       |    4 +-
 src/core/{na-exporter.c => fma-exporter.c} |   48 ++++++++++++++--------------
 src/core/{na-exporter.h => fma-exporter.h} |   36 ++++++++++----------
 src/nact/nact-assistant-export.c           |   10 +++---
 src/nact/nact-clipboard.c                  |    6 ++--
 src/nact/nact-export-ask.c                 |    6 ++--
 src/nact/nact-preferences-editor.c         |    8 ++--
 src/utils/nautilus-actions-new.c           |    4 +-
 src/utils/nautilus-actions-print.c         |    6 ++--
 9 files changed, 64 insertions(+), 64 deletions(-)
---
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 84ae9c1..6f92b37 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -60,8 +60,8 @@ libna_core_la_SOURCES = \
        fma-data-types.c                                                                                \
        fma-desktop-environment.c                                                       \
        fma-desktop-environment.h                                                       \
-       na-exporter.c                                                                           \
-       na-exporter.h                                                                           \
+       fma-exporter.c                                                                          \
+       fma-exporter.h                                                                          \
        na-export-format.c                                                                      \
        na-export-format.h                                                                      \
        na-factory-object.c                                                                     \
diff --git a/src/core/na-exporter.h b/src/core/fma-exporter.h
similarity index 58%
rename from src/core/na-exporter.h
rename to src/core/fma-exporter.h
index 6f87e99..11fd345 100644
--- a/src/core/na-exporter.h
+++ b/src/core/fma-exporter.h
@@ -27,12 +27,12 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __CORE_NA_EXPORTER_H__
-#define __CORE_NA_EXPORTER_H__
+#ifndef __CORE_FMA_EXPORTER_H__
+#define __CORE_FMA_EXPORTER_H__
 
 /* @title: FMAIExporter
  * @short_description: The #FMAIExporter Internal Functions
- * @include: core/na-exporter.h
+ * @include: core/fma-exporter.h
  */
 
 #include <api/fma-iexporter.h>
@@ -46,24 +46,24 @@ G_BEGIN_DECLS
 #define EXPORTER_FORMAT_ASK                            "Ask"
 #define EXPORTER_FORMAT_NOEXPORT               "NoExport"
 
-GList       *na_exporter_get_formats    ( const NAPivot *pivot );
-void         na_exporter_free_formats   ( GList *formats );
-NAIOption   *na_exporter_get_ask_option ( void );
+GList        *fma_exporter_get_formats    ( const NAPivot *pivot );
+void          fma_exporter_free_formats   ( GList *formats );
+NAIOption   *fma_exporter_get_ask_option ( void );
 
-gchar       *na_exporter_to_buffer      ( const NAPivot *pivot,
-                                          const FMAObjectItem *item,
-                                          const gchar *format,
-                                          GSList **messages );
+gchar        *fma_exporter_to_buffer      ( const NAPivot *pivot,
+                                            const FMAObjectItem *item,
+                                            const gchar *format,
+                                            GSList **messages );
 
-gchar       *na_exporter_to_file        ( const NAPivot *pivot,
-                                          const FMAObjectItem *item,
-                                          const gchar *folder_uri,
-                                          const gchar *format,
-                                          GSList **messages );
+gchar        *fma_exporter_to_file        ( const NAPivot *pivot,
+                                            const FMAObjectItem *item,
+                                            const gchar *folder_uri,
+                                            const gchar *format,
+                                            GSList **messages );
 
-FMAIExporter *na_exporter_find_for_format( const NAPivot *pivot,
-                                                 const gchar *format );
+FMAIExporter *fma_exporter_find_for_format( const NAPivot *pivot,
+                                                   const gchar *format );
 
 G_END_DECLS
 
-#endif /* __CORE_NA_EXPORTER_H__ */
+#endif /* __CORE_FMA_EXPORTER_H__ */
diff --git a/src/nact/nact-assistant-export.c b/src/nact/nact-assistant-export.c
index 2aa4c24..e156bfa 100644
--- a/src/nact/nact-assistant-export.c
+++ b/src/nact/nact-assistant-export.c
@@ -37,7 +37,7 @@
 #include "api/fma-core-utils.h"
 #include "api/fma-object-api.h"
 
-#include "core/na-exporter.h"
+#include "core/fma-exporter.h"
 #include "core/na-export-format.h"
 #include "core/na-gtk-utils.h"
 #include "core/na-ioptions-list.h"
@@ -209,7 +209,7 @@ ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container
 
        application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
        updater = nact_application_get_updater( application );
-       formats = na_exporter_get_formats( NA_PIVOT( updater ));
+       formats = fma_exporter_get_formats( NA_PIVOT( updater ));
 
        return( formats );
 }
@@ -217,13 +217,13 @@ ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container
 static void
 ioptions_list_free_formats( const NAIOptionsList *instance, GtkWidget *container, GList *formats )
 {
-       na_exporter_free_formats( formats );
+       fma_exporter_free_formats( formats );
 }
 
 static NAIOption *
 ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container )
 {
-       return( na_exporter_get_ask_option());
+       return( fma_exporter_get_ask_option());
 }
 
 static void
@@ -789,7 +789,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
                }
 
                if( strcmp( str->format, EXPORTER_FORMAT_NOEXPORT ) != 0 ){
-                       str->fname = na_exporter_to_file( NA_PIVOT( updater ), str->item, 
window->private->uri, str->format, &str->msg );
+                       str->fname = fma_exporter_to_file( NA_PIVOT( updater ), str->item, 
window->private->uri, str->format, &str->msg );
                }
 
                g_free( str->format );
diff --git a/src/nact/nact-clipboard.c b/src/nact/nact-clipboard.c
index d42fb8b..104055a 100644
--- a/src/nact/nact-clipboard.c
+++ b/src/nact/nact-clipboard.c
@@ -36,7 +36,7 @@
 
 #include "api/fma-object-api.h"
 
-#include "core/na-exporter.h"
+#include "core/fma-exporter.h"
 #include "core/na-export-format.h"
 
 #include "nact-application.h"
@@ -627,11 +627,11 @@ export_row_object( NactClipboard *clipboard, FMAObject *object, const gchar *des
 
                if( strcmp( format, EXPORTER_FORMAT_NOEXPORT ) != 0 ){
                        if( dest_folder ){
-                               fname = na_exporter_to_file( NA_PIVOT( updater ), item, dest_folder, format, 
&msgs );
+                               fname = fma_exporter_to_file( NA_PIVOT( updater ), item, dest_folder, format, 
&msgs );
                                g_free( fname );
 
                        } else {
-                               buffer = na_exporter_to_buffer( NA_PIVOT( updater ), item, format, &msgs );
+                               buffer = fma_exporter_to_buffer( NA_PIVOT( updater ), item, format, &msgs );
                                if( buffer && strlen( buffer )){
                                        data = g_string_append( data, buffer );
                                        g_free( buffer );
diff --git a/src/nact/nact-export-ask.c b/src/nact/nact-export-ask.c
index 5da3662..a848c41 100644
--- a/src/nact/nact-export-ask.c
+++ b/src/nact/nact-export-ask.c
@@ -35,7 +35,7 @@
 
 #include "api/fma-object-api.h"
 
-#include "core/na-exporter.h"
+#include "core/fma-exporter.h"
 #include "core/na-export-format.h"
 #include "core/na-gtk-utils.h"
 #include "core/na-ioptions-list.h"
@@ -165,7 +165,7 @@ ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container
 
        application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
        updater = nact_application_get_updater( application );
-       formats = na_exporter_get_formats( NA_PIVOT( updater ));
+       formats = fma_exporter_get_formats( NA_PIVOT( updater ));
 
        return( formats );
 }
@@ -173,7 +173,7 @@ ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container
 static void
 ioptions_list_free_formats( const NAIOptionsList *instance, GtkWidget *container, GList *formats )
 {
-       na_exporter_free_formats( formats );
+       fma_exporter_free_formats( formats );
 }
 
 static void
diff --git a/src/nact/nact-preferences-editor.c b/src/nact/nact-preferences-editor.c
index 494a3d9..d25010c 100644
--- a/src/nact/nact-preferences-editor.c
+++ b/src/nact/nact-preferences-editor.c
@@ -37,7 +37,7 @@
 #include <api/fma-iimporter.h>
 
 #include <core/fma-desktop-environment.h>
-#include <core/na-exporter.h>
+#include <core/fma-exporter.h>
 #include <core/na-export-format.h>
 #include <core/na-gtk-utils.h>
 #include <core/na-import-mode.h>
@@ -268,7 +268,7 @@ ioptions_list_get_options( const NAIOptionsList *instance, GtkWidget *container
        if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesExportFormatVBox" )){
                application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
                updater = nact_application_get_updater( application );
-               options = na_exporter_get_formats( NA_PIVOT( updater ));
+               options = fma_exporter_get_formats( NA_PIVOT( updater ));
 
        } else if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesImportModeVBox" 
)){
                options = na_importer_get_modes();
@@ -290,7 +290,7 @@ ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container
        g_return_if_fail( NACT_IS_PREFERENCES_EDITOR( instance ));
 
        if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesExportFormatVBox" )){
-               na_exporter_free_formats( options );
+               fma_exporter_free_formats( options );
 
        } else if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesImportModeVBox" 
)){
                na_importer_free_modes( options );
@@ -313,7 +313,7 @@ ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *contain
        option = NULL;
 
        if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesExportFormatVBox" )){
-               option = na_exporter_get_ask_option();
+               option = fma_exporter_get_ask_option();
 
        } else if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesImportModeVBox" 
)){
                option = na_importer_get_ask_mode();
diff --git a/src/utils/nautilus-actions-new.c b/src/utils/nautilus-actions-new.c
index b4564fb..7640756 100644
--- a/src/utils/nautilus-actions-new.c
+++ b/src/utils/nautilus-actions-new.c
@@ -44,7 +44,7 @@
 
 #include <core/na-gconf-migration.h>
 #include <core/na-io-provider.h>
-#include <core/na-exporter.h>
+#include <core/fma-exporter.h>
 #include <core/na-updater.h>
 
 #include "console-utils.h"
@@ -609,7 +609,7 @@ output_to_stdout( const FMAObjectAction *action, GSList **msgs )
        gchar *buffer;
 
        updater = na_updater_new();
-       buffer = na_exporter_to_buffer( NA_PIVOT( updater ), FMA_OBJECT_ITEM( action ), "Desktop1", msgs );
+       buffer = fma_exporter_to_buffer( NA_PIVOT( updater ), FMA_OBJECT_ITEM( action ), "Desktop1", msgs );
        ret = ( buffer != NULL );
 
        if( buffer ){
diff --git a/src/utils/nautilus-actions-print.c b/src/utils/nautilus-actions-print.c
index d49a228..d47549c 100644
--- a/src/utils/nautilus-actions-print.c
+++ b/src/utils/nautilus-actions-print.c
@@ -41,7 +41,7 @@
 #include <api/fma-core-utils.h>
 #include <api/fma-object-api.h>
 
-#include <core/na-exporter.h>
+#include <core/fma-exporter.h>
 #include <core/na-export-format.h>
 #include <core/na-ioption.h>
 
@@ -135,7 +135,7 @@ main( int argc, char** argv )
                format = "Desktop1";
        }
 
-       exporter = na_exporter_find_for_format( pivot, format );
+       exporter = fma_exporter_find_for_format( pivot, format );
        if( !exporter ){
                /* i18n: %s stands for the id of the export format, and is not translatable */
                g_printerr( _( "Error: %s: unknown export format.\n" ), format );
@@ -218,7 +218,7 @@ export_item( const FMAObjectItem *item, const gchar *format )
        GSList *messages = NULL;
        GSList *it;
 
-       gchar *buffer = na_exporter_to_buffer( pivot, item, format, &messages );
+       gchar *buffer = fma_exporter_to_buffer( pivot, item, format, &messages );
 
        for( it = messages ; it ; it = it->next ){
                g_printerr( "%s\n", ( const gchar * ) it->data );


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/core/na-exporter.c b/src/core/fma-exporter.c
similarity index 91%
rename from src/core/na-exporter.c
rename to src/core/fma-exporter.c
index 331cb9a..9de86ac 100644
--- a/src/core/na-exporter.c
+++ b/src/core/fma-exporter.c
@@ -35,7 +35,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
-#include "na-exporter.h"
+#include "fma-exporter.h"
 #include "na-export-format.h"
 #include "na-settings.h"
 
@@ -65,17 +65,17 @@ static gchar *exporter_get_name( const FMAIExporter *exporter );
 static void   on_pixbuf_finalized( gpointer user_data, GObject *pixbuf );
 
 /*
- * na_exporter_get_formats:
+ * fma_exporter_get_formats:
  * @pivot: the #NAPivot instance.
  *
  * Returns: a list of #NAExportFormat objects, each of them addressing an
  * available export format, i.e. a format provided by a module which
  * implement the #FMAIExporter interface.
  *
  * The returned list should later be na_exporter_free_formats() by the caller.
  */
 GList *
-na_exporter_get_formats( const NAPivot *pivot )
+fma_exporter_get_formats( const NAPivot *pivot )
 {
        GList *iexporters, *imod;
        GList *formats;
@@ -173,16 +173,16 @@ exporter_free_formats( const FMAIExporter *exporter, GList *str_list )
 }
 
 /*
- * na_exporter_free_formats:
+ * fma_exporter_free_formats:
  * @formats: a list of available export formats, as returned by
- *  na_exporter_get_formats().
+ *  fma_exporter_get_formats().
  *
  * Release the @formats #GList.
  */
 void
-na_exporter_free_formats( GList *formats )
+fma_exporter_free_formats( GList *formats )
 {
-       static const gchar *thisfn = "na_exporter_free_formats";
+       static const gchar *thisfn = "fma_exporter_free_formats";
 
        g_debug( "%s: formats=%p (count=%d)", thisfn, ( void * ) formats, g_list_length( formats ));
 
@@ -191,16 +191,16 @@ na_exporter_free_formats( GList *formats )
 }
 
 /*
- * na_exporter_get_ask_option:
+ * fma_exporter_get_ask_option:
  *
  * Returns the 'Ask me' option.
  *
  * Since: 3.2
  */
 NAIOption *
-na_exporter_get_ask_option( void )
+fma_exporter_get_ask_option( void )
 {
-       static const gchar *thisfn = "na_exporter_get_ask_option";
+       static const gchar *thisfn = "fma_exporter_get_ask_option";
        FMAIExporterFormatv2 *str;
        gint width, height;
        gchar *fname;
@@ -242,11 +242,11 @@ na_exporter_get_ask_option( void )
 static void
 on_pixbuf_finalized( gpointer user_data /* ==NULL */, GObject *pixbuf )
 {
-       g_debug( "na_exporter_on_pixbuf_finalized: pixbuf=%p", ( void * ) pixbuf );
+       g_debug( "fma_exporter_on_pixbuf_finalized: pixbuf=%p", ( void * ) pixbuf );
 }
 
 /*
- * na_exporter_to_buffer:
+ * fma_exporter_to_buffer:
  * @pivot: the #NAPivot pivot for the running application.
  * @item: a #FMAObjectItem-derived object.
  * @format: the target format identifier.
@@ -259,10 +259,10 @@ on_pixbuf_finalized( gpointer user_data /* ==NULL */, GObject *pixbuf )
  * be g_free() by the caller, or %NULL if an error has been detected.
  */
 gchar *
-na_exporter_to_buffer( const NAPivot *pivot,
+fma_exporter_to_buffer( const NAPivot *pivot,
                const FMAObjectItem *item, const gchar *format, GSList **messages )
 {
-       static const gchar *thisfn = "na_exporter_to_buffer";
+       static const gchar *thisfn = "fma_exporter_to_buffer";
        gchar *buffer;
        FMAIExporterBufferParmsv2 parms;
        FMAIExporter *exporter;
@@ -281,7 +281,7 @@ na_exporter_to_buffer( const NAPivot *pivot,
                        format,
                        ( void * ) messages );
 
-       exporter = na_exporter_find_for_format( pivot, format );
+       exporter = fma_exporter_find_for_format( pivot, format );
        g_debug( "%s: exporter=%p (%s)", thisfn, ( void * ) exporter, G_OBJECT_TYPE_NAME( exporter ));
 
        if( exporter ){
@@ -317,7 +317,7 @@ na_exporter_to_buffer( const NAPivot *pivot,
 }
 
 /*
- * na_exporter_to_file:
+ * fma_exporter_to_file:
  * @pivot: the #NAPivot pivot for the running application.
  * @item: a #FMAObjectItem-derived object.
  * @folder_uri: the URI of the target folder.
@@ -331,10 +331,10 @@ na_exporter_to_buffer( const NAPivot *pivot,
  * should be g_free() by the caller, or %NULL if an error has been detected.
  */
 gchar *
-na_exporter_to_file( const NAPivot *pivot,
+fma_exporter_to_file( const NAPivot *pivot,
                const FMAObjectItem *item, const gchar *folder_uri, const gchar *format, GSList **messages )
 {
-       static const gchar *thisfn = "na_exporter_to_file";
+       static const gchar *thisfn = "fma_exporter_to_file";
        gchar *export_uri;
        FMAIExporterFileParmsv2 parms;
        FMAIExporter *exporter;
@@ -354,7 +354,7 @@ na_exporter_to_file( const NAPivot *pivot,
                        format,
                        ( void * ) messages );
 
-       exporter = na_exporter_find_for_format( pivot, format );
+       exporter = fma_exporter_find_for_format( pivot, format );
 
        if( exporter ){
                parms.version = 2;
@@ -404,7 +404,7 @@ exporter_get_name( const FMAIExporter *exporter )
 }
 
 /**
- * na_exporter_find_for_format:
+ * fma_exporter_find_for_format:
  * @pivot: the #NAPivot instance.
  * @format: the string identifier of the searched format.
  *
@@ -413,7 +413,7 @@ exporter_get_name( const FMAIExporter *exporter )
  * released by the caller.
  */
 FMAIExporter *
-na_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
+fma_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
 {
        FMAIExporter *exporter;
        GList *formats, *ifmt;
@@ -423,7 +423,7 @@ na_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
        g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
 
        exporter = NULL;
-       formats = na_exporter_get_formats( pivot );
+       formats = fma_exporter_get_formats( pivot );
 
        for( ifmt = formats ; ifmt && !exporter ; ifmt = ifmt->next ){
 
@@ -435,7 +435,7 @@ na_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
                g_free( id );
        }
 
-       na_exporter_free_formats( formats );
+       fma_exporter_free_formats( formats );
 
        return( exporter );
 }
@@ -65,17 +65,17 @@ static gchar *exporter_get_name( const FMAIExporter *exporter );
  * implement the #FMAIExporter interface.
  *
- * The returned list should later be na_exporter_free_formats() by the caller.
+ * The returned list should later be fma_exporter_free_formats() by the caller.
  */
 GList *